@@ -2,7 +2,7 @@
 
     PCMCIA Card Manager daemon
 
-    cardmgr.c 1.158 2001/05/12 22:45:59
+    cardmgr.c 1.161 2001/08/24 12:19:19
 
     The contents of this file are subject to the Mozilla Public
     License Version 1.1 (the "License"); you may not use this file
@@ -19,8 +19,8 @@
     are Copyright (C) 1999 David A. Hinds.  All Rights Reserved.
 
     Alternatively, the contents of this file may be used under the
-    terms of the GNU Public License version 2 (the "GPL"), in which
-    case the provisions of the GPL are applicable instead of the
+    terms of the GNU General Public License version 2 (the "GPL"), in
+    which case the provisions of the GPL are applicable instead of the
     above.  If you wish to allow the use of your version of this file
     only under the terms of the GPL and not to allow others to use
     your version of this file under the MPL, indicate your decision
@@ -321,12 +321,15 @@ static void write_stab(void)
 #endif
     for (i = 0; i < sockets; i++) {
 	s = &socket[i];
-	if (!(s->state & SOCKET_PRESENT))
-	    fprintf(f, "Socket %d: empty\n", i);
-	else if (!s->card)
-	    fprintf(f, "Socket %d: unsupported card\n", i);
-	else {
-	    fprintf(f, "Socket %d: %s\n", i, s->card->name);
+	fprintf(f, "Socket %d: ", i);
+	if (!(s->state & SOCKET_PRESENT)) {
+	    fprintf(f, "empty\n");
+	} else if (s->state & SOCKET_HOTPLUG) {
+	    fprintf(f, "CardBus hotplug device\n");
+	} else if (!s->card) {
+	    fprintf(f, "unsupported card\n");
+	} else {
+	    fprintf(f, "%s\n", s->card->name);
 	    for (j = 0; j < s->card->bindings; j++)
 		for (k = 0, bind = s->bind[j];
 		     bind != NULL;
@@ -387,51 +390,15 @@ typedef struct pci_id {
     struct pci_id *next;
 } pci_id_t;
 
-pci_id_t *hotplug_list = NULL;
-
-static void load_pcimap(void)
-{
-    char s[133], *fn = malloc(strlen(modpath) + 20);
-    int v, d;
-    FILE *f;
-
-    strcpy(fn, modpath);
-    strcat(fn, "/modules.pcimap");
-    f = fopen(fn, "r");
-    if (!f) return;
-
-    while (fgets(s, 132, f) != NULL) {
-	if (sscanf(s, "%*s %x %x", &v, &d) == 2) {
-	    pci_id_t *e = malloc(sizeof *e);
-	    e->vendor = v; e->device = d;
-	    e->next = hotplug_list;
-	    hotplug_list = e;
-	}
-    }
-    fclose(f);
-}
-
 static int get_pci_id(int ns, pci_id_t *id)
 {
     socket_info_t *s = &socket[ns];
     config_info_t config;
-    char fn[50];
-    int fd;
 
     config.Function = config.ConfigBase = 0;
     if ((ioctl(s->fd, DS_GET_CONFIGURATION_INFO, &config) != 0) ||
-	(config.IntType != INT_CARDBUS))
+	(config.IntType != INT_CARDBUS) || !config.ConfigBase)
 	return 0;
-    if (config.ConfigBase) {
-	/* this indicates non-hotplug PCMCIA support */
-	hotplug_list = NULL;
-    } else {
-	sprintf(fn, "/proc/bus/pci/%02d/00.0", config.Option);
-	if ((fd = open(fn, O_RDONLY)) < 0)
-	    return 0;
-	read(fd, &config.ConfigBase, 4);
-	close(fd);
-    }
     id->vendor = config.ConfigBase & 0xffff;
     id->device = config.ConfigBase >> 16;
     return 1;
@@ -484,8 +451,7 @@ static card_info_t *lookup_card(int ns)
     pci_id_t pci_id = { 0, 0 };
     cistpl_funcid_t funcid = { 0xff, 0xff };
     cs_status_t status;
-    int i, ret, match;
-    int has_cis = 0;
+    int i, ret, has_cis = 0;
 
     /* Do we have a CIS structure? */
     ret = ioctl(s->fd, DS_VALIDATE_CIS, &arg);
@@ -506,13 +472,15 @@ static card_info_t *lookup_card(int ns)
 	if (get_tuple(ns, CISTPL_VERS_1, &arg) == 0)
 	    vers = &arg.tuple_parse.parse.version_1;
 
-	match = 0;
 	for (card = root_card; card; card = card->next) {
-	    switch (card->ident_type) {
-		
-	    case VERS_1_IDENT:
+
+	    if (card->ident_type &
+		~(VERS_1_IDENT|MANFID_IDENT|TUPLE_IDENT))
+		continue;
+
+	    if (card->ident_type & VERS_1_IDENT) {
 		if (vers == NULL)
-		    break;
+		    continue;
 		for (i = 0; i < card->id.vers.ns; i++) {
 		    if (strcmp(card->id.vers.pi[i], "*") == 0)
 			continue;
@@ -523,56 +491,54 @@ static card_info_t *lookup_card(int ns)
 			break;
 		}
 		if (i < card->id.vers.ns)
-		    break;
-		match = 1;
-		break;
-
-	    case MANFID_IDENT:
-		if ((manfid.manf == card->id.manfid.manf) &&
-		    (manfid.card == card->id.manfid.card))
-		    match = 1;
-		break;
+		    continue;
+	    }
+	    
+	    if (card->ident_type & MANFID_IDENT) {
+		if ((manfid.manf != card->manfid.manf) ||
+		    (manfid.card != card->manfid.card))
+		    continue;
+	    }
 		
-	    case TUPLE_IDENT:
+	    if (card->ident_type & TUPLE_IDENT) {
 		arg.tuple.DesiredTuple = card->id.tuple.code;
 		arg.tuple.Attributes = 0;
 		ret = ioctl(s->fd, DS_GET_FIRST_TUPLE, &arg);
-		if (ret != 0) break;
+		if (ret != 0) continue;
 		arg.tuple.TupleOffset = card->id.tuple.ofs;
 		ret = ioctl(s->fd, DS_GET_TUPLE_DATA, &arg);
-		if (ret != 0) break;
+		if (ret != 0) continue;
 		if (strncmp((char *)arg.tuple_parse.data,
 			    card->id.tuple.info,
 			    strlen(card->id.tuple.info)) != 0)
-		    break;
-		match = 1;
-		break;
-
-	    default:
-		/* Skip */
-		break;
+		    continue;
 	    }
-	    if (match) break;
+
+	    break; /* we have a match */
 	}
     }
 
     /* Check PCI vendor/device info */
-    if (get_pci_id(ns, &pci_id)) {
-	pci_id_t *p;
-	if (!card) {
-	    for (card = root_card; card; card = card->next)
-		if ((card->ident_type == PCI_IDENT) &&
-		    (pci_id.vendor == card->id.manfid.manf) &&
-		    (pci_id.device == card->id.manfid.card))
-		    break;
-	}
-	for (p = hotplug_list; p; p = p->next)
-	    if ((pci_id.vendor == p->vendor) &&
-		(pci_id.device == p->device)) break;
-	if (p)
+    status.Function = 0;
+    ioctl(s->fd, DS_GET_STATUS, &status);
+    if (status.CardState & CS_EVENT_CB_DETECT) {
+	if (get_pci_id(ns, &pci_id)) {
+	    if (!card) {
+		for (card = root_card; card; card = card->next)
+		    if ((card->ident_type == PCI_IDENT) &&
+			(pci_id.vendor == card->manfid.manf) &&
+			(pci_id.device == card->manfid.card))
+			break;
+	    }
+	} else {
+	    /* this is a 2.4 kernel; hotplug handles these cards */
 	    s->state |= SOCKET_HOTPLUG;
+	    syslog(LOG_INFO, "socket %d: CardBus hotplug device", ns);
+	    //beep(BEEP_TIME, BEEP_OK);
+	    return NULL;
+	}
     }
-    
+
     /* Try for a FUNCID match */
     if (!card && (funcid.func != 0xff)) {
 	for (card = root_func; card; card = card->next)
@@ -587,7 +553,6 @@ static card_info_t *lookup_card(int ns)
 	return card;
     }
 
-    status.Function = 0;
     if (!blank_card || (status.CardState & CS_EVENT_CB_DETECT) ||
 	manfid.manf || manfid.card || pci_id.vendor || vers) {
 	syslog(LOG_INFO, "unsupported card in socket %d", ns);
@@ -995,18 +960,18 @@ static void do_insert(int sn)
     /* Already identified? */
     if ((s->card != NULL) && (s->card != blank_card))
 	return;
-    
-    syslog(LOG_INFO, "initializing socket %d", sn);
+
+    if (verbose) syslog(LOG_INFO, "initializing socket %d", sn);
     card = lookup_card(sn);
+    if (s->state & SOCKET_HOTPLUG) {
+	write_stab();
+	return;
+    }
     /* Make sure we've learned something new before continuing */
     if (card == s->card)
 	return;
     s->card = card;
     card->refs++;
-    if (s->state & SOCKET_HOTPLUG) {
-	write_stab();
-	return;
-    }
     if (card->cis_file) update_cis(s);
 
     dev = card->device;
@@ -1086,10 +1051,7 @@ static void do_insert(int sn)
     for (i = ret = 0; i < card->bindings; i++)
 	if (dev[i]->class)
 	    ret |= execute_on_all("start", dev[i]->class, sn, i);
-    if (ret)
-	beep(BEEP_TIME, BEEP_ERR);
-    else
-	beep(BEEP_TIME, BEEP_OK);
+    beep(BEEP_TIME, (ret) ? BEEP_ERR : BEEP_OK);
     
 }
 
@@ -1128,14 +1090,12 @@ static void do_remove(int sn)
     bind_info_t *bind;
     int i, j;
 
+    if (verbose) syslog(LOG_INFO, "shutting down socket %d", sn);
+
     card = s->card;
     if (card == NULL)
 	goto done;
-    
-    syslog(LOG_INFO, "shutting down socket %d", sn);
-    if (s->state & SOCKET_HOTPLUG)
-	goto done;
-    
+
     /* Run "stop" commands */
     dev = card->device;
     for (i = 0; i < card->bindings; i++) {
@@ -1495,7 +1455,6 @@ int main(int argc, char *argv[])
 	syslog(LOG_INFO, "cannot access %s: %m", modpath);
     /* We default to using modprobe if it is available */
     do_modprobe |= (access("/sbin/modprobe", X_OK) == 0);
-    load_pcimap();
 #endif /* __linux__ */
     
     load_config();
