@@ -59,7 +59,7 @@
 #include <linux/init.h>
 #include <linux/sched.h>
 #include <linux/ptrace.h>
-#include <linux/malloc.h>
+#include <linux/slab.h>
 #include <linux/string.h>
 #include <linux/timer.h>
 #include <linux/module.h>
@@ -88,13 +88,6 @@ static char *version =
 #define DEBUG(n, args...)
 #endif
 
-/* Dumb test for new ibmtr driver */
-#ifdef BLOCKSZ
-#define TR_OLD 0
-#else
-#define TR_OLD 1
-#endif
-
 /*====================================================================*/
 
 /* Parameters that can be set with 'insmod' */
@@ -468,6 +461,9 @@ static void ibmtr_release(u_long arg)
     if (link->win) {
 	struct tok_info *ti = dev->priv;
 	iounmap((void *)ti->mmio);
+#if !(TR_OLD)
+	iounmap((void *)ti->sram_virt);
+#endif
 	CardServices(ReleaseWindow, link->win);
 	CardServices(ReleaseWindow, info->sram_win_handle);
     }
